#!/usr/bin/env python
# Coolan Confidential
# Copyright (c) Coolan, Inc 2014 All Rights Reserved
#
# NOTICE:  All information contained herein is, and remains
# the property of Coolan, Inc.  The intellectual and
# technical concepts contained #herein are proprietary to
# Coolan, Inc and may be covered by U.S. and Foreign Patents,
# patents in process, and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material
# is strictly forbidden unless prior written permission is obtained
# from Coolan, Inc.
# This code and information are provided "as is" without warranty of any
# kind, either expressed or implied, including but not limited to the
# implied warranties of mechantability and/or fitness for a
# particular purpose.

from datetime import timedelta
import glob

from common import *


def remove_old_logs():
    try:
        verify_root()

        remove_old_logs_in_folder(get_backup_folder_path(), ".zip", config.get(s.SETTINGS, 'backup_logs_keep_days'))
        remove_old_logs_in_folder(get_logs_folder_path(), s.TMP_FILE_EXTENSION, config.get(s.SETTINGS, 'tmp_logs_keep_days'))
        if is_config_on('clean_up_old_custom_logs'):
            remove_old_logs_in_folder(get_custom_backup_folder_path(), ".zip", config.get(s.SETTINGS, 'backup_logs_keep_days'))
    except:
        print_fail("%s : Failed cleaning up logs." % get_timestamp())
        exc_type, exc_value, exc_traceback = sys.exc_info()
        traceback.print_exception(exc_type, exc_value, exc_traceback, limit=2, file=sys.stdout)
        os._exit(1)
    finally:
        sys.stdout.flush()


def remove_old_logs_in_folder(folder_path, extension, old_logs_keep_days):
    print "%s : Started cleaning up %s logs older than %s days in %s." % (get_timestamp(), extension, old_logs_keep_days, folder_path)
    count = 0
    for file_path in glob.glob(folder_path + "/*" + extension):
        file_modified = datetime.fromtimestamp(os.path.getmtime(file_path))
        if datetime.now() - file_modified > timedelta(days=int(old_logs_keep_days)):
            os.remove(file_path)
            count += 1
    print "%s : Finished cleaning up logs older than %s days in %s. %s files have been removed." % (get_timestamp(), old_logs_keep_days, folder_path, count)


if __name__ == "__main__":
    remove_old_logs()
