#!/usr/bin/env python
# Coolan Confidential
# Copyright (c) Coolan, Inc 2014 All Rights Reserved
#
# NOTICE:  All information contained herein is, and remains
# the property of Coolan, Inc.  The intellectual and
# technical concepts contained #herein are proprietary to
# Coolan, Inc and may be covered by U.S. and Foreign Patents,
# patents in process, and are protected by trade secret or copyright law.
# Dissemination of this information or reproduction of this material
# is strictly forbidden unless prior written permission is obtained
# from Coolan, Inc.
# This code and information are provided "as is" without warranty of any
# kind, either expressed or implied, including but not limited to the
# implied warranties of mechantability and/or fitness for a
# particular purpose.

from common import *
import errno
import signal
from distutils.dir_util import copy_tree, DistutilsFileError

coolan_mcelog_directory = os.path.join(script_path, 'mcelog')
mcelog_config_destination = os.path.join('/', config.get(s.DIRECTORIES, 'mcelog_config').strip())
optional_triggers_directory = os.path.join(mcelog_config_destination, 'triggers')
backup_folder = os.path.join('/', config.get(s.DIRECTORIES, 'mcelog_backup').strip())


def mcelog_setup():
    print "%s : Start setting up mcelog configuration." % get_timestamp()
    try:
        os.makedirs(backup_folder)
    except OSError as exc:
        if exc.errno == errno.EEXIST and os.path.isdir(backup_folder):
            pass
        else:
            print_fail("%s : There was an error setting up the mcelog triggers. %s" % (get_timestamp(), exc))
    try:
        files = os.listdir(backup_folder)
        if len(files) > 0:
            print_fail("%s : There backup folder %s is not empty. Skip setting up mcelog configuration." % (get_timestamp(), backup_folder))
            return
        # copy all the default mcelog config files to a backup folder
        copy_tree(mcelog_config_destination, backup_folder)
        # if optional triggers directory (e.g. /etc/mcelog/triggers) exists, copy contents to /etc/mcelog
        if os.path.isdir(optional_triggers_directory):
            copy_tree(optional_triggers_directory, mcelog_config_destination)
        # copy all the Coolan mcelog config to the mcelog config folder
        copy_tree(coolan_mcelog_directory, mcelog_config_destination)
        # kill the mcelog process
        out, err = get_command_output(args=['ps', '-A'])
        for line in out.splitlines():
            if r'.*mcelog.*' in line:
                pid = int(line.split(None, 1)[0])  # gets PID of mcelog
                os.kill(pid, signal.SIGKILL)
        mcelog_full_path = find_command("mcelog")
        if mcelog_full_path:
            output, error = get_command_output(args=[mcelog_full_path, '--daemon'])
            print "%s : Restart mcelog as a daemon." % get_timestamp()
        if not mcelog_full_path or error.strip():
            print "%s : Cannot start mcelog as daemon: mcelog doesn't exist" % get_timestamp()
        else:
            print "%s : Finish setting up mcelog configuration." % get_timestamp()
    except DistutilsFileError as e:
        print_fail("%s : There was an error setting up the mcelog triggers. %s" % (get_timestamp(), e))
    except:
        print_fail("%s : There was an error setting up the mcelog triggers" % get_timestamp())
        exc_type, exc_value, exc_traceback = sys.exc_info()
        traceback.print_exception(exc_type, exc_value, exc_traceback, limit=2, file=sys.stdout)